@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Colin Ian King 2015-2021
+ * Copyright (C) Colin Ian King 2015-2023
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -330,7 +330,7 @@ static pid_t proc_name_to_pid(char *const name)
  */
 static const char *get_proc_self_stat_field(const char *buf, const int num)
 {
-	const char *ptr = buf, *comm_end;
+	const char *ptr, *comm_end;
 	int n;
 
 	if (num < 1 || !buf || !*buf)
@@ -651,7 +651,7 @@ static void show_vm(void)
 	}
 
 	if (!read_oom_score(&score)) {
-		(void)mvwprintw(g.mainwin, y++, x,
+		(void)mvwprintw(g.mainwin, y, x,
 			" OOM Score: %8" PRIu64 "    ", score);
 	}
 }
@@ -822,7 +822,7 @@ static int show_pages(
 
 		for (j = 0; j < xmax; j++) {
 			char state = '.';
-			int attr = COLOR_PAIR(BLACK_WHITE);
+			int attr;
 
 			if (idx >= (index_t)g.mem_info.npages) {
 				attr = COLOR_PAIR(BLACK_BLACK);
